summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--rubygems_plugin.rb12
1 files changed, 6 insertions, 6 deletions
diff --git a/rubygems_plugin.rb b/rubygems_plugin.rb
index 84eeba7..42f50ba 100644
--- a/rubygems_plugin.rb
+++ b/rubygems_plugin.rb
@@ -1,12 +1,12 @@
-# Make sure there are no `done_installing` hooks defined yet, so there is know
-# starting position.
-raise unless Gem.done_installing_hooks.empty?
-
# Initialize the RubyGems RDoc hook.
require "rubygems/rdoc"
-# Double check that there is only one `done_installing` hook loaded.
-raise unless Gem.done_installing_hooks.size == 1
+# Make sure there is only one `done_installing`, so we can assume it it the
+# RDod defined one.
+raise <<~ERR unless Gem.done_installing_hooks.size == 1
+ rdoc-generator-fedora-darkfish expects only one `Gem.done_installing_hooks`
+ at this stage, but #{Gem.done_installing_hooks.size} are defined
+ERR
# Subsequently drop the hook.
Gem.done_installing_hooks.pop